import regex as re
import csv
from glob import glob

# Get raw package text from latex file
def extract_text(filename,index):

    #Open file
    data = open(filename).read()

    #Strip comments
    comments = re.findall(r'%(.*?)\n', data, re.S)
    for comment in comments:
        comment = "%" + comment + "\n"
        data = data.replace(comment,"")

    # Extract work packages
    workps = re.findall(r'\\begin{workp}(.*?)\\end{workp}', data, re.S)

    # Add index
    results = []
    for i,wp in enumerate(workps):
        myitem = {"index":str(index)+"."+str(i+1),"wp":wp}
        results.append(myitem)
    
    return results

# Format the work packages into a list of data
def format_wp(index,wp_s):
    name = wp_s.split("[")[1].split("]")[0]

    if wp_s.split("}\n")[1].lstrip()[1:5] == "wpin":
        text = wp_s.split("\n")[3:]
    else:
        text = wp_s.split("\n")[1:-3]
    text = "\n".join(text)
    text = text.lstrip().rstrip()
    wpin = wp_s.split("\wpin")[1].split("\wpout")[0].rstrip()[1:-1]
    wpout = wp_s.split("\wpout")[1].split("}\n")[0][1:]
    return [index,name,text,wpin,wpout]


#Get filenames, and sort
filenames = glob("*.tex")
filenames.sort()

# Extract all the work packages from the files
workps = []
for i,filename in enumerate(filenames):
    workps += extract_text(filename,i+1)

labels = ["Index","Name","Package","Inputs","Deliverables"]
table = [labels]

#Format the wps
for wp in workps:
    formatted_wp = format_wp(wp["index"],wp["wp"])
    table.append(formatted_wp)

#Write to csv
with open('work_packages.csv', 'w', newline='') as f:
    writer = csv.writer(f)
    writer.writerows(table)